@@ -24,6 +24,9 @@ BACKUP_JOB_LABELS = COMMON_LABELS + [
     'backup_vault_name',
 ]
 
+BACKUP_JOB_COLLECTOR_SUCCESS = Gauge(
+    'aws_backup_job_collector_success', 'AWS Backup job collector success', COMMON_LABELS)
+
 BACKUP_JOB_SIZE_BYTES = Gauge(
     'aws_backup_job_size_bytes', 'AWS Backup job size in bytes', BACKUP_JOB_LABELS)
 BACKUP_JOB_PERCENT_DONE = Gauge(
@@ -31,8 +34,11 @@ BACKUP_JOB_PERCENT_DONE = Gauge(
 
 BACKUP_VAULT_LABELS = COMMON_LABELS + ['backup_vault_name']
 
+BACKUP_VAULT_COLLECTOR_SUCCESS = Gauge(
+    'aws_backup_vault_collector_success', 'AWS Backup vault collector success', COMMON_LABELS)
+
 BACKUP_VAULT_RECOVERY_POINTS = Gauge(
-    'aws_backup_recovery_points', 'AWS Backup vault number of recovery points', BACKUP_VAULT_LABELS)
+    'aws_backup_vault_recovery_points', 'AWS Backup vault number of recovery points', BACKUP_VAULT_LABELS)
 
 ###############################################################################
 # AWS SNS push notifications
@@ -41,6 +47,9 @@ SNS_PLATFORM_APPLICATION_LABELS = COMMON_LABELS + [
     'sns_platform_application_name'
 ]
 
+SNS_PLATFORM_APPLICATION_COLLECTOR_SUCCESS = Gauge(
+    'sns_platform_application_collector_success', 'AWS SNS platform application collector success', COMMON_LABELS)
+
 SNS_PLATFORM_APPLICATION_ENABLED = Gauge(
     'sns_platform_application_enabled', 'AWS SNS platform application enabled', SNS_PLATFORM_APPLICATION_LABELS)
 
