@@ -9,8 +9,11 @@
 
 import boto3
 
+from functools import lru_cache
+
 STS = boto3.client('sts')
 
 
+@lru_cache(maxsize=None)
 def get_account_id():
     return STS.get_caller_identity()['Account']
