@@ -7,6 +7,16 @@
 #
 # THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
+import logging
+import sys
+
+from functools import wraps
+
+from aws_exporter.sts import get_account_id
+
+
+LOGGER = logging.getLogger(__name__)
+
 
 def paginate(data_function, process_function):
     response = data_function()
@@ -17,4 +27,18 @@ def paginate(data_function, process_function):
         if 'NextToken' not in response:
             break
 
-        response = data_function(response['NextToken'])
+        response = data_function(NextToken=response['NextToken'])
+
+def success_metric(metric):
+    def decorator(collector_function):
+        @wraps(collector_function)
+        def function_wrapper(*args, **kwargs):
+            try:
+                return collector_function(*args, **kwargs)
+            except Exception as exc:
+                LOGGER.exception('caught exception in collector function')
+            finally:
+                metric.labels(get_account_id()).set(0 if sys.exc_info()[0] is not None else 1)
+
+        return function_wrapper
+    return decorator
