@@ -12,10 +12,10 @@ from aws_exporter.util import paginate
 
 
 def test_paginate():
-    def produce(token=None):
-        if token == 'END':
+    def produce(NextToken=None):
+        if NextToken == 'END':
             return dict()
-        elif token == 'START':
+        elif NextToken == 'START':
             return dict(NextToken='END')
         else:
             return dict(NextToken='START')
